@@ -4,8 +4,7 @@
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef TESTTODOTOOLTIP_H
-#define TESTTODOTOOLTIP_H
+#pragma once
 
 #include <QObject>
 
@@ -28,4 +27,3 @@ private Q_SLOTS:
     void testPriority();
 };
 
-#endif
