@@ -58,13 +58,13 @@ public:
         }
     }
 
-    ~ScopeWidget();
+    ~ScopeWidget() override;
 
     void setMessage(const QString &message);
     void setIcon(const QIcon &icon);
 
     void setCheckedChoices(int choices);
-    int checkedChoices() const;
+    Q_REQUIRED_RESULT int checkedChoices() const;
 
 private:
     const int mAvailableChoices;
@@ -197,7 +197,7 @@ int RecurrenceActions::questionSelectedAllCancel(const QString &message,
 {
     QPointer<QDialog> dialog = new QDialog(parent);
     dialog->setWindowTitle(caption);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::No | QDialogButtonBox::Yes, parent);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::No | QDialogButtonBox::Yes, parent);
     dialog->setObjectName(QStringLiteral("RecurrenceActions::questionSelectedAllCancel"));
 
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Yes), actionSelected);
@@ -232,7 +232,7 @@ int RecurrenceActions::questionSelectedFutureAllCancel(const QString &message,
     QPointer<QDialog> dialog = new QDialog(parent);
     dialog->setWindowTitle(caption);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::No | QDialogButtonBox::Yes, parent);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::No | QDialogButtonBox::Yes, parent);
     dialog->setObjectName(QStringLiteral("RecurrenceActions::questionSelectedFutureAllCancel"));
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::Yes), actionSelected);
     KGuiItem::assign(buttonBox->button(QDialogButtonBox::No), actionFuture);
